summaryrefslogtreecommitdiff
path: root/passwd/apr_getpass.c
diff options
context:
space:
mode:
authordougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2001-02-08 07:45:23 +0000
committerdougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2001-02-08 07:45:23 +0000
commitaba88e6ebce8d24a8ca387c28aabc9f17559a56c (patch)
tree136752321dd3e22c22463c9ab35a700ab0507729 /passwd/apr_getpass.c
parent482ce86a79d41d751123dcfcfc29f4098135c4b7 (diff)
downloadlibapr-aba88e6ebce8d24a8ca387c28aabc9f17559a56c.tar.gz
renaming various functions for consistency sake
see: http://apr.apache.org/~dougm/apr_rename.pl PR: Obtained from: Submitted by: Reviewed by: git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@61194 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'passwd/apr_getpass.c')
-rw-r--r--passwd/apr_getpass.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/passwd/apr_getpass.c b/passwd/apr_getpass.c
index 92d849b17..6a9be850f 100644
--- a/passwd/apr_getpass.c
+++ b/passwd/apr_getpass.c
@@ -52,7 +52,7 @@
* <http://www.apache.org/>.
*/
/* apr_getpass.c: abstraction to provide for obtaining a password from the
* command line in whatever way the OS supports. In the best case, it's a
* wrapper for the system library's getpass() routine; otherwise, we
* use one we define ourselves.
@@ -212,7 +212,7 @@ static char *getpass(const char *prompt)
* but the caller is *not* made aware of it.
*/
-APR_DECLARE(apr_status_t) apr_getpass(const char *prompt, char *pwbuf, size_t *bufsiz)
+APR_DECLARE(apr_status_t) apr_password_get(const char *prompt, char *pwbuf, size_t *bufsiz)
{
char *pw_got = NULL;
int result = 0;
@@ -52,7 +52,7 @@
* <http://www.apache.org/>.
*/
-/* apr_getpass.c: abstraction to provide for obtaining a password from the
+/* apr_password_get.c: abstraction to provide for obtaining a password from the
* command line in whatever way the OS supports. In the best case, it's a
* wrapper for the system library's getpass() routine; otherwise, we